==> istio-model-v1alpha3-6.6.0-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl<A extends EnvoyFilterRouteConfigurationMatchRouteMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterRouteConfigurationMatchRouteMatchFluent<A>{
  public EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl() {
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl(EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    this.withAction(instance.getAction()); 
    this.withName(instance.getName()); 
  }
  private EnvoyFilterRouteConfigurationMatchRouteMatchAction action;
  private String name;
  public EnvoyFilterRouteConfigurationMatchRouteMatchAction getAction() {
    return this.action;
  }
  public A withAction(EnvoyFilterRouteConfigurationMatchRouteMatchAction action) {
    this.action=action; return (A) this;
  }
  public Boolean hasAction() {
    return this.action != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl that = (EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl) o;
    if (action != null ? !action.equals(that.action) :that.action != null) return false;
    if (name != null ? !name.equals(that.name) :that.name != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> istio-model-v1alpha3-6.7.2-sources.jar: io/fabric8/istio/api/networking/v1alpha3/EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl.java <==
package io.fabric8.istio.api.networking.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl<A extends EnvoyFilterRouteConfigurationMatchRouteMatchFluent<A>> extends BaseFluent<A> implements EnvoyFilterRouteConfigurationMatchRouteMatchFluent<A>{
  public EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl() {
  }
  public EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl(EnvoyFilterRouteConfigurationMatchRouteMatch instance) {
    if (instance != null) {
      this.withAction(instance.getAction());
      this.withName(instance.getName());
    }
  }
  private EnvoyFilterRouteConfigurationMatchRouteMatchAction action;
  private String name;
  public EnvoyFilterRouteConfigurationMatchRouteMatchAction getAction() {
    return this.action;
  }
  public A withAction(EnvoyFilterRouteConfigurationMatchRouteMatchAction action) {
    this.action=action; return (A) this;
  }
  public Boolean hasAction() {
    return this.action != null;
  }
  public String getName() {
    return this.name;
  }
  public A withName(String name) {
    this.name=name; return (A) this;
  }
  public Boolean hasName() {
    return this.name != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl that = (EnvoyFilterRouteConfigurationMatchRouteMatchFluentImpl) o;
    if (!java.util.Objects.equals(action, that.action)) return false;

    if (!java.util.Objects.equals(name, that.name)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(action,  name,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (action != null) { sb.append("action:"); sb.append(action + ","); }
    if (name != null) { sb.append("name:"); sb.append(name); }
    sb.append("}");
    return sb.toString();
  }
  
}
